@@ -1,4 +1,7 @@
-def varint(x: int, inverted=False):
+from typing import Tuple
+
+
+def varint(x: int, inverted: bool = False) -> bytes:
     buf = b''
     while True:
         towrite = x & 0x7f
@@ -12,11 +15,11 @@ def varint(x: int, inverted=False):
     return buf
 
 
-def varstr(s: bytes, inverted=False):
+def varstr(s: bytes, inverted: bool = False) -> bytes:
     return varint(len(s), inverted=inverted) + s
 
 
-def process_varint(payload, inverted=False):
+def process_varint(payload: bytes, inverted: bool = False) -> Tuple[int, int]:
     """Read a varint from `stream`"""
     shift = 0
     result = 0
@@ -31,6 +34,6 @@ def process_varint(payload, inverted=False):
     return result, count
 
 
-def process_varstr(payload, inverted=False):
+def process_varstr(payload: bytes, inverted: bool = False) -> Tuple[bytes, int]:
     n, length = process_varint(payload, inverted=inverted)
     return payload[length:length + n], length + n
